import path from 'node:path'
import { fileURLToPath, URL } from 'node:url'

import VueI18nPlugin from '@intlify/unplugin-vue-i18n/vite'
import vue from '@vitejs/plugin-vue'
import colors from 'picocolors'
import UnoCSS from 'unocss/vite'
import AutoImport from 'unplugin-auto-import/vite'
import TurboConsole from 'unplugin-turbo-console/vite'
import Components from 'unplugin-vue-components/vite'
import { defineConfig } from 'vite'
import nightwatchPlugin from 'vite-plugin-nightwatch'
import vueDevTools from 'vite-plugin-vue-devtools'

// https://vite.dev/config/
export default defineConfig({
  plugins: [
    vue(),
    vueDevTools(),
    nightwatchPlugin(),
    UnoCSS(),
    Components({
      dts: true,
    }),
    AutoImport({
      imports: [
        'vue',
        'vue-router',
        'vue-i18n',
        'vitest',
        'pinia',
        '@vueuse/core',
      ],
      vueTemplate: true,
      vueDirectives: true,
    }),
    TurboConsole({
      silent: true,
      disablePassLogs: true,
    }),
    VueI18nPlugin({
      include: [path.resolve(__dirname, './src/locales/**')],
    }),
    {
      name: 'nextvs-startup-logo',
      configureServer: (server) => {
        const { printUrls } = server
        server.printUrls = () => {
          console.log(`  🚀 ${colors.bold(colors.red('NEXTVS'))} ${colors.dim('up and running')}`)
          printUrls()
        }
      },
    },
  ],
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url)),
    },
  },
  server: {
    port: 8080,
    proxy: {
      '^/api/openapi.json': {
        target: 'https://netvs-devel.scc.kit.edu',
        secure: true,
        changeOrigin: true,
        followRedirects: true,
      },
      '^/api': {
        target: 'https://netvs-devel.scc.kit.edu',
        secure: false,
        changeOrigin: false,
        toProxy: true,
        followRedirects: true,
      },
      '^/hub': {
        target: 'https://netvs-devel.scc.kit.edu',
        secure: true,
        changeOrigin: true,
        followRedirects: true,
      },
    },
  },
})
